@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: vector-algorithms
 version: 0.7.0.1
-id: vector-algorithms-0.7.0.1-35e55e2e8e51824728ed456b5a330a6b
-key: vecto_0wekAXy6uoCFoww5dP6hc7
+id: vector-algorithms-0.7.0.1-7844ad1f07fd0916dddd070104841af1
+key: vecto_2O3XZ6glbAwDmJCc3dC3Ee
 license: BSD3
 copyright: (c) 2008,2009,2010,2011,2012,2013,2014,2015 Dan Doel
            (c) 2015 Tim Baumann
@@ -26,7 +26,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/vector-algorithms-0.7.0.1
-hs-libraries: HSvector-algorithms-0.7.0.1-0wekAXy6uoCFoww5dP6hc7
+hs-libraries: HSvector-algorithms-0.7.0.1-2O3XZ6glbAwDmJCc3dC3Ee
 include-dirs: /usr/lib/ghc-7.10.3/site-local/vector-algorithms-0.7.0.1/include
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
